==> nextcloud-30.0.2.tgz: nextcloud/apps/federatedfilesharing/l10n/ar.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "معرف السحابة الموحدة غير صحيح",
    "Server to server sharing is not enabled on this server" : "المُشاركة من خادم إلى خادم غير مُمكّنة على هذا الخادم",
    "Couldn't establish a federated share." : "تعذّر تأسيس مُشاركة السحابة الموحدة.",
    "Couldn't establish a federated share, maybe the password was wrong." : "تعذّر تأسيس مُشاركة السحابة الموحدة. ربما بسبب كلمة مرور غير صحيحة",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "تمّ إرسال طلب مُشاركة السحابة الموحدة. سوف تصلك دعوة. رجاءً، تحقّق من إشعاراتك.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "تعذّر تأسيس مُشاركة السحابة الموحدة. يبدو أن إصدار خادم نكست كلاود الذي طلبت الاتحاد معه قديمٌ ( ما قبل الإصدار 9). ",
    "It is not allowed to send federated group shares from this server." : "غيرُ مسموحٍ بإرسال مشاركات مجموعات السحابة الموحدة من هذا الخادم.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "فشلت مشاركة %1$s بسبب أن هذه العنصر سبقت مشاركته مع الحساب  %2$s",
    "Not allowed to create a federated share to the same account" : "غير مسموح بإنشاء مشاركة السحابة الموحدة لنفس الحساب",
    "Federated shares require read permissions" : "مشاركات السحابة الموحدة تتطلب إذونات قراءة",
    "File is already shared with %s" : "سبقت مُشاركة الملف مع %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "المُشاركة %1$s فشلت؛ تعذّر إيجاد %2$s. يُمكن أن يكون هذ بسبب أن الخادم لا يُمكن الوصول إليه حاليّاً أو أنه يستعمل شهادةً ذاتيّة التصديق self-signed certificate.",
    "Could not find share" : "تعذّر العثور على المُشاركة",
    "Federated sharing" : "مُشاركة السحابة الموحدة",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "أنت تلقيت {share} كُمشاركة بعيدة من {user} (نيابةً عن {behalf})",
    "You received {share} as a remote share from {user}" : "أنت تلقّيتَ {share} كُمشاركة بعيدة من {user}  ",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Federated Cloud Sharing" : "المشاركة عبر السحابة الموحّدة",
    "Sharing" : "المشاركة",
    "Federated file sharing" : "مُشاركة السحابة الموحدة لملف",
    "Provide federated file sharing across servers" : "توفير مُشاركة السحابة الموحدة للملفات عبر الخوادم",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "اضبط كيفية مشاركة الأشخاص بين الخوادم. و يشمل ذلك المشاركات بين الأشخاص على هذا الخادم أيضاً إذا كانوا يستعملون المشاركة عبر السحابة الموحدة.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "إسمَح للأشخاص على هذا الخادم بإرسال مشاركات إلى خوادم أخرى (هذا الخيار يسمح أيضاً بالوصول عبر WebDAV إلى المشاركات العمومية)",
    "Allow people on this server to receive shares from other servers" : "إسمَح للأشخاص على هذا الخادم باستقبال مشاركات من خوادم أخرى",
    "Allow people on this server to send shares to groups on other servers" : "إسمَح للأشخاص على هذا الخادم بإرسال مشاركات إلى مجموعات على خوادم أخرى",
    "Allow people on this server to receive group shares from other servers" : "إسمَح للأشخاص على هذا الخادم بإستقبال مشاركات لمجموعات من خوادم أخرى",
    "Search global and public address book for people" : "البحث في دفتر العناوين الشامل و دفاتر العناوين العامة للأشخاص",
    "Allow people to publish their data to a global and public address book" : "إسمَح للأشخاص بنشر بياناتهم إلى دفتر العناوين الشامل و دفتر العناوين العامة للأشخاص",
    "Unable to update federated files sharing config" : "تعذر تحديث تهيئة مُشاركة الملفات عبر السحابة الموحدة",
    "Federated Cloud" : "السحابة الموحدة",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "يُمكنك المشاركة مع أي شخص يستخدم خادم نكست كلاود أو خوادم وخدمات أخرى متوافقة مع بروتوكول Open Cloud Mesh (OCM)! فقط ضع مُعرّف السحابة الموحدة Federated Cloud في مربع حوار المُشاركة؛ و الذي سيكون شكله على هذا النسق: person@cloud.example.com",
    "Your Federated Cloud ID" : "مُعرِّف شبكتك الاتحادية",
    "Share it so your friends can share files with you:" : "شاركه مع أصدقائك بحيث يمكنهم مُشاركة الملفات معك:",
    "Facebook" : "فيسبوك",
    "X (formerly Twitter)" : "منصة X (تويتر سابقاً)",
    "formerly Twitter" : "تويتر سابقاً",
    "Mastodon" : "برنامج ماستودون Mastodon",
    "Add to your website" : "أضف إلى موقعك على الويب",
    "Share with me via Nextcloud" : "شاركه معي عبر النكست كلاود",
    "HTML Code:" : "كود HTML: ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الموحدة Nextcloud Federated Cloud ID، أنظر {url} ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الموحدة Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "تمّ نسخ معرف السحابة إلى الحافظة",
    "Copy to clipboard" : "نسخ الرابط",
    "Clipboard not available. Please copy the cloud ID manually." : "الحافظة غير متوفرة. رجاءً، قم بنسخ مُعرِّف السحابة يدوياً.",
    "Copied!" : "تم نسخه !",
    "Cancel" : "إلغاء",
    "Add remote share" : "إضافة مشاركة بعيدة remote",
    "Remote share" : "مُشاركة بعيدة remote",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "هل ترغب في إضافة مُشاركة بعيدة remote ـ {name} من {owner}@{remote}؟",
    "Remote share password" : "كلمة مرور مشاركة بعيدة remote",
    "Incoming share could not be processed" : "لا يمكن معالجة المشاركة الواردة",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "مُشاركة %1$s فشلت؛ بسبب أن هذا العنصر سبقت مُشاركته مع المُستخدِم %2$s ",
    "Not allowed to create a federated share with the same user" : "غيرُ مسموحٍ أن تُنشيء مُشاركةً السحابة الموحدة مع نفس المُستخدِم",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "ضبط كيف يتشارك الأشخاص عبر الخوادم. و هذا يشمل المشاركات بين المستخدمين على هذا الخادم و ما بين الخوادم عبر السحابة الموحدة كذلك.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "تمكين المستخدمين على هذا الخادم من إرسال مُشاركاتٍ إلى خوادم أخرى ( هذا الخيار يُتيح أيضاً الوصول إلى المُشاركات العمومية عن طريق البروتوكول WebDAV )",
    "Allow users on this server to receive shares from other servers" : "تمكين المستخدمين على هذا الخادم من استقبال مُشاركاتٍ من خوادم أخرى",
    "Allow users on this server to send shares to groups on other servers" : "تمكين المستخدمين على هذا الخادم من إرسال مُشاركات إلى مجموعاتٍ على خوادم أخرى",
    "Allow users on this server to receive group shares from other servers" : "تمكين المستخدمين على هذا الخادم من استقبال مُشاركاتٍ من مجموعاتٍ على خوادم أخرى",
    "Search global and public address book for users" : "البحث في سجلات العناوين العمومية public و الشاملة glabal عن مُستخدِمين",
    "Allow users to publish their data to a global and public address book" : "تمكين المستخدمين من نشر بياناتهم في سجلات العناوين الشاملة و العمومية",
    "Your Federated Cloud ID:" : "معرف السحابة الموحدة الخاص بك:",
    "Twitter" : "تويتر",
    "Diaspora" : "دياسبورا",
    "Clipboard is not available" : "الحافظة غير متوافرة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/ar.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "معرف السحابة الموحدة غير صحيح",
    "Server to server sharing is not enabled on this server" : "المُشاركة من خادم إلى خادم غير مُمكّنة على هذا الخادم",
    "Couldn't establish a federated share." : "تعذّر تأسيس مُشاركة السحابة الموحدة.",
    "Couldn't establish a federated share, maybe the password was wrong." : "تعذّر تأسيس مُشاركة السحابة الموحدة. ربما بسبب كلمة مرور غير صحيحة",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "تمّ إرسال طلب مُشاركة السحابة الموحدة. سوف تصلك دعوة. رجاءً، تحقّق من إشعاراتك.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "تعذّر تأسيس مُشاركة السحابة الموحدة. يبدو أن إصدار خادم نكست كلاود الذي طلبت الاتحاد معه قديمٌ ( ما قبل الإصدار 9). ",
    "It is not allowed to send federated group shares from this server." : "غيرُ مسموحٍ بإرسال مشاركات مجموعات السحابة الموحدة من هذا الخادم.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "فشلت مشاركة %1$s بسبب أن هذه العنصر سبقت مشاركته مع الحساب  %2$s",
    "Not allowed to create a federated share to the same account" : "غير مسموح بإنشاء مشاركة السحابة الموحدة لنفس الحساب",
    "Federated shares require read permissions" : "مشاركات السحابة الموحدة تتطلب إذونات قراءة",
    "File is already shared with %s" : "سبقت مُشاركة الملف مع %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "المُشاركة %1$s فشلت؛ تعذّر إيجاد %2$s. يُمكن أن يكون هذ بسبب أن الخادم لا يُمكن الوصول إليه حاليّاً أو أنه يستعمل شهادةً ذاتيّة التصديق self-signed certificate.",
    "Could not find share" : "تعذّر العثور على المُشاركة",
    "Federated sharing" : "مُشاركة السحابة الموحدة",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "أنت تلقيت {share} كُمشاركة بعيدة من {user} (نيابةً عن {behalf})",
    "You received {share} as a remote share from {user}" : "أنت تلقّيتَ {share} كُمشاركة بعيدة من {user}  ",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Federated Cloud Sharing" : "المشاركة عبر السحابة الموحّدة",
    "Sharing" : "المشاركة",
    "Federated file sharing" : "مُشاركة السحابة الموحدة لملف",
    "Provide federated file sharing across servers" : "توفير مشاركة السحابة الموحدة للملفات عبر الخوادم",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "اضبط كيفية مشاركة الأشخاص بين الخوادم. و يشمل ذلك المشاركات بين الأشخاص على هذا الخادم أيضاً إذا كانوا يستعملون المشاركة عبر السحابة الموحدة.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "السماح للأشخاص على هذا الخادم بإرسال مشاركات إلى خوادم أخرى (هذا الخيار يسمح أيضاً بالوصول عبر WebDAV إلى المشاركات العمومية)",
    "Allow people on this server to receive shares from other servers" : "السماح للأشخاص على هذا الخادم باستقبال مشاركات من خوادم أخرى",
    "Allow people on this server to send shares to groups on other servers" : "السماح للأشخاص على هذا الخادم بإرسال مشاركات إلى مجموعات على خوادم أخرى",
    "Allow people on this server to receive group shares from other servers" : "السماح للأشخاص على هذا الخادم بإستقبال مشاركات لمجموعات من خوادم أخرى",
    "Search global and public address book for people" : "البحث في دفتر العناوين الشامل و دفاتر العناوين العامة للأشخاص",
    "Allow people to publish their data to a global and public address book" : "السماح للأشخاص بنشر بياناتهم إلى دفتر العناوين الشامل و دفتر العناوين العامة للأشخاص",
    "Trusted federation" : "إتحاد موثوق",
    "Automatically accept shares from trusted federated accounts and groups by default" : "يتم آليّاً قبول المشاركات من حسابات ومجموعات الاتحادات الموثوقة بشكل تلقائي ",
    "Unable to update federated files sharing config" : "تعذر تحديث تهيئة مشاركة الملفات عبر السحابة الموحدة",
    "Federated Cloud" : "السحابة الموحدة",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "يُمكنك المشاركة مع أي شخص يستخدم خادم نكست كلاود أو خوادم وخدمات أخرى متوافقة مع بروتوكول Open Cloud Mesh (OCM)! فقط ضع مُعرّف السحابة الموحدة Federated Cloud في مربع حوار المُشاركة؛ و الذي سيكون شكله على هذا النسق: person@cloud.example.com",
    "Your Federated Cloud ID" : "مُعرِّف شبكتك الاتحادية",
    "Share it so your friends can share files with you:" : "شاركه مع أصدقائك بحيث يمكنهم مُشاركة الملفات معك:",
    "Facebook" : "فيسبوك",
    "X (formerly Twitter)" : "منصة X (تويتر سابقاً)",
    "formerly Twitter" : "تويتر سابقاً",
    "Mastodon" : "برنامج ماستودون Mastodon",
    "Add to your website" : "أضف إلى موقعك على الويب",
    "Share with me via Nextcloud" : "شاركه معي عبر النكست كلاود",
    "HTML Code:" : "كود HTML: ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الموحدة Nextcloud Federated Cloud ID، أنظر {url} ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الموحدة Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "تمّ نسخ معرف السحابة إلى الحافظة",
    "Copy to clipboard" : "نسخ الرابط",
    "Clipboard not available. Please copy the cloud ID manually." : "الحافظة غير متوفرة. رجاءً، قم بنسخ مُعرِّف السحابة يدوياً.",
    "Copied!" : "تم نسخه !",
    "Cancel" : "إلغاء",
    "Add remote share" : "إضافة مشاركة بعيدة remote",
    "Remote share" : "مُشاركة بعيدة remote",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "هل ترغب في إضافة مُشاركة بعيدة remote ـ {name} من {owner}@{remote}؟",
    "Remote share password" : "كلمة مرور مشاركة بعيدة remote",
    "Incoming share could not be processed" : "لا يمكن معالجة المشاركة الواردة",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "مُشاركة %1$s فشلت؛ بسبب أن هذا العنصر سبقت مُشاركته مع المُستخدِم %2$s ",
    "Not allowed to create a federated share with the same user" : "غيرُ مسموحٍ أن تُنشيء مُشاركةً السحابة الموحدة مع نفس المُستخدِم",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "ضبط كيف يتشارك الأشخاص عبر الخوادم. و هذا يشمل المشاركات بين المستخدمين على هذا الخادم و ما بين الخوادم عبر السحابة الموحدة كذلك.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "تمكين المستخدمين على هذا الخادم من إرسال مُشاركاتٍ إلى خوادم أخرى ( هذا الخيار يُتيح أيضاً الوصول إلى المُشاركات العمومية عن طريق البروتوكول WebDAV )",
    "Allow users on this server to receive shares from other servers" : "تمكين المستخدمين على هذا الخادم من استقبال مُشاركاتٍ من خوادم أخرى",
    "Allow users on this server to send shares to groups on other servers" : "تمكين المستخدمين على هذا الخادم من إرسال مُشاركات إلى مجموعاتٍ على خوادم أخرى",
    "Allow users on this server to receive group shares from other servers" : "تمكين المستخدمين على هذا الخادم من استقبال مُشاركاتٍ من مجموعاتٍ على خوادم أخرى",
    "Search global and public address book for users" : "البحث في سجلات العناوين العمومية public و الشاملة glabal عن مُستخدِمين",
    "Allow users to publish their data to a global and public address book" : "تمكين المستخدمين من نشر بياناتهم في سجلات العناوين الشاملة و العمومية",
    "Your Federated Cloud ID:" : "معرف السحابة الموحدة الخاص بك:",
    "Twitter" : "تويتر",
    "Diaspora" : "دياسبورا",
    "Clipboard is not available" : "الحافظة غير متوافرة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
